@@ -1,5 +1,4 @@
 use super::*;
-use srtp::stream::Stream;
 
 #[derive(Default, Clone)]
 pub(crate) struct PeerConnectionInternal {
@@ -545,15 +544,13 @@ impl PeerConnectionInternal {
     /// Start all transports. PeerConnection now has enough state
     pub(super) async fn start_transports(
         self: &Arc<Self>,
-        _ice_role: ICERole,
-        _dtls_role: DTLSRole,
-        _remote_ufrag: String,
-        _remote_pwd: String,
-        _fingerprint: String,
-        _fingerprint_hash: String,
+        ice_role: ICERole,
+        dtls_role: DTLSRole,
+        remote_ufrag: String,
+        remote_pwd: String,
+        fingerprint: String,
+        fingerprint_hash: String,
     ) {
-        //TODO:
-        /*
         // Start the ice transport
         if let Err(err) = self
             .ice_transport
@@ -592,7 +589,7 @@ impl PeerConnectionInternal {
         .await;
         if let Err(err) = result {
             log::warn!("Failed to start manager: {}", err);
-        }*/
+        }
     }
 
     /// generate_unmatched_sdp generates an SDP that doesn't take remote state into account
